@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubs.f90 10304 2009-08-20 09:05:43Z andrewross $
+!  $Id: sfstubs.f90 11005 2010-05-18 12:56:14Z andrewross $
 !  sfstubs.f
 !
 !  Copyright (C) 2004  Alan W. Irwin
@@ -791,41 +791,6 @@
 
       end subroutine
 
-!***********************************************************************
-
-      subroutine plmap(mapform,mapname,minx,maxx,miny,maxy)
-
-      implicit none
-      real(kind=plflt) minx, maxx, miny, maxy
-      character*(*) mapname
-      external mapform
-
-      include 'sfstubs.h'
-
-      call plstrf2c(mapname, string1, maxlen)
-
-      call plsetmapformc(mapform)
-      s1 = transfer( string1, s1 )
-      call plmap7(s1,minx,maxx,miny,maxy)
-
-      end subroutine
-
-!***********************************************************************
-
-      subroutine plmeridians(mapform,dlong,dlat,minlong,maxlong, &
-                             minlat,maxlat)
-
-      implicit none
-      real(kind=plflt) dlong, dlat, minlong, maxlong, minlat, maxlat
-      external mapform
-
-      include 'sfstubs.h'
-
-      call plsetmapformc(mapform)
-      call plmeridians7(dlong,dlat,minlong,maxlong,minlat,maxlat)
-
-      end subroutine
-
 !***********************************************************************
 
       subroutine pltimefmt(fmt)
