@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubsf95.f90 9133 2008-12-16 14:12:45Z andrewross $
+!  $Id: sfstubsf95.f90 11005 2010-05-18 12:56:14Z andrewross $
 !  sfstubsf95.f
 !
 !  Copyright (C) 2005, 2006  Arjen Markus
@@ -401,6 +401,10 @@
          end subroutine plgra
       end interface
 
+      interface plgradient
+         module procedure plgradient
+      end interface
+
       interface plgriddata
          module procedure plgriddata
       end interface
@@ -501,6 +505,14 @@
          end subroutine pllsty
       end interface
 
+      interface plmap
+         module procedure plmap1, plmap2
+      end interface plmap
+
+      interface plmeridians
+         module procedure plmeridians1, plmeridians2
+      end interface plmeridians
+
       interface plmesh
          module procedure plmesh
       end interface
@@ -749,6 +761,29 @@
          end subroutine plsfont
       end interface
 
+      interface plslabelfunc
+          subroutine plslabelfunc_on( labelfunc )
+              interface
+                  subroutine labelfunc(axis, value, label, length)
+                      use plplot_flt
+                      implicit none
+                      integer :: axis, length
+                      real(kind=plflt) :: value
+                      character*(length) label
+                  end subroutine labelfunc
+              end interface
+          end subroutine plslabelfunc_on
+
+          subroutine plslabelfunc_off( dummy )
+              implicit none
+              integer :: dummy
+          end subroutine plslabelfunc_off
+
+          subroutine plslabelfunc_none
+          end subroutine plslabelfunc_none
+
+      end interface
+
       interface
          subroutine plsmaj( def, scale )
             use plplot_flt
@@ -808,6 +843,27 @@
          end subroutine plstar
       end interface
 
+      interface plstransform
+          subroutine plstransform1( transformfunc )
+              interface
+                  subroutine transformfunc(x, y, xt, yt)
+                      use plplot_flt
+                      implicit none
+                      real(kind=plflt) :: x, y, xt, yt
+                  end subroutine transformfunc
+              end interface
+          end subroutine plstransform1
+
+          subroutine plstransform2( dummy )
+              implicit none
+              integer :: dummy
+          end subroutine plstransform2
+
+          subroutine plstransform3
+          end subroutine plstransform3
+
+      end interface
+
       interface
          subroutine plstripa( id, pen, x, y )
             use plplot_flt
@@ -986,6 +1042,13 @@
          call plfill3f77( size(x), x, y, z )
       end subroutine plfill3
 
+      subroutine plgradient( x, y, angle )
+         real(kind=plflt), dimension(:) :: x, y
+         real(kind=plflt)               :: angle
+
+         call plgradientf77( size(x), x, y, angle )
+      end subroutine plgradient
+
       subroutine plgriddata( x, y, z, xg, yg, zg, type, data )
          real(kind=plflt), dimension(:)   :: x, y, z, xg, yg
          real(kind=plflt), dimension(:,:) :: zg
@@ -1047,6 +1110,67 @@
          call plline3f77( size(x), x, y, z )
       end subroutine plline3
 
+      subroutine plmap1(mapform,mapname,minx,maxx,miny,maxy) 
+        use plplot_flt
+        implicit none
+        real(kind=plflt) minx, maxx, miny, maxy
+        character*(*) mapname
+        external mapform
+        
+        include 'sfstubs.h'
+        
+        call plstrf2c(mapname, string1, maxlen)
+        
+        call plsetmapformc(mapform)
+        s1 = transfer( string1, s1 )
+        call plmap7(s1,minx,maxx,miny,maxy)
+        
+      end subroutine plmap1
+      
+      subroutine plmap2(mapname,minx,maxx,miny,maxy)
+        use plplot_flt
+        implicit none
+        real(kind=plflt) minx, maxx, miny, maxy
+        character*(*) mapname
+        
+        include 'sfstubs.h'
+        
+        call plstrf2c(mapname, string1, maxlen)
+        
+        call plclearmapformc()
+        s1 = transfer( string1, s1 )
+        call plmap7(s1,minx,maxx,miny,maxy)
+        
+      end subroutine plmap2
+
+      subroutine plmeridians1(mapform,dlong,dlat,minlong,maxlong, &
+                             minlat,maxlat)
+
+      implicit none
+      real(kind=plflt) dlong, dlat, minlong, maxlong, minlat, maxlat
+      external mapform
+
+      include 'sfstubs.h'
+
+      call plsetmapformc(mapform)
+      call plmeridians7(dlong,dlat,minlong,maxlong,minlat,maxlat)
+
+      end subroutine plmeridians1
+
+      subroutine plmeridians2(dlong,dlat,minlong,maxlong, &
+                             minlat,maxlat)
+
+      implicit none
+      real(kind=plflt) dlong, dlat, minlong, maxlong, minlat, maxlat
+      external mapform
+
+      include 'sfstubs.h'
+
+      call plclearmapformc
+      call plmeridians7(dlong,dlat,minlong,maxlong,minlat,maxlat)
+
+      end subroutine plmeridians2
+
       subroutine plmesh( x, y, z, opt )
          integer                          :: opt
          real(kind=plflt), dimension(:)   :: x, y
