@@ -1,4 +1,4 @@
-/* $Id: psttf.cc 9708 2009-03-10 23:52:24Z airwin $
+/* $Id: psttf.cc 11047 2010-06-01 08:49:36Z andrewross $
 
 	PLplot PostScript device driver using LASi to provide fonts
 	based on original ps.c PostScript driver
@@ -626,7 +626,7 @@ plD_tidy_psttf(PLStream *pls)
       doc->write(cout,dev->llx,dev->lly,dev->urx,dev->ury);
     }
     else {      
-      fclose(pls->OutFile);
+      plCloseFile( pls );
       ofstream out;
       out.open(pls->FileName);
       doc->write(out,dev->llx,dev->lly,dev->urx,dev->ury);
@@ -805,7 +805,7 @@ void
 proc_str (PLStream *pls, EscText *args)
 {
   PLFLT *t = args->xform, tt[4]; /* Transform matrices */
-  PLFLT theta;  /* Rotation angle and shear from the matrix */
+  PLFLT theta, shear, stride;  /* Rotation angle and shear from the matrix */
   PLFLT ft_ht, offset; /* Font height and offset */
   PLFLT cs,sn;
   PSDev *dev = (PSDev *) pls->dev;
@@ -907,10 +907,9 @@ proc_str (PLStream *pls, EscText *args)
 	
 	
 	/* The transform matrix has only rotations and shears; extract them */
-	theta = acos(t[0]) * 180. / PI;  /* Determine the rotation (in degrees)... */
-	if (t[2] < 0.) theta *= -1.;     /* ... and sign ... */
-	cs = cos(theta*PI/180.);
-	sn = sin(theta*PI/180.);
+        plRotationShear( t, &theta, &shear, &stride );
+	cs = cos(theta);
+	sn = sin(theta);
 	tt[0] = t[0]*cs + t[2]*sn;
 	tt[1] = t[1]*cs + t[3]*sn;
 	tt[2] = -t[0]*sn + t[2]*cs;
@@ -936,16 +935,16 @@ proc_str (PLStream *pls, EscText *args)
 	  offset = -ENLARGE * ft_ht / 2.;
 	
 	/* Determine the adjustment for page orientation */
-	theta -= 90.*pls->diorot;
-	args->y += (int) (offset*cos(theta*PI/180.));
-	args->x -= (int) (offset*sin(theta*PI/180.));
+	theta -= PI/2.*pls->diorot;
+	args->y += (int) (offset*cos(theta));
+	args->x -= (int) (offset*sin(theta));
 		
 	/* ps driver is rotated by default */
 	plRotPhy(ORIENTATION, dev->xmin, dev->ymin, dev->xmax, dev->ymax, 
 		 &(args->x), &(args->y));
 	
 	/* Correct for the fact ps driver uses landscape by default */
-	theta += 90.;
+	theta += PI/2.;
 	
 	/* Output */
 	/* Set clipping */
@@ -974,7 +973,7 @@ proc_str (PLStream *pls, EscText *args)
 	doc->osBody() << " " << args->x << " " << args->y << " M\n";
 	
 	/* Save the current position and set the string rotation */
-	doc->osBody() << "gsave " << TRMFLT(theta) << " R\n";
+	doc->osBody() << "gsave " << TRMFLT(theta*180./PI) << " R\n";
 
 	doc->osBody() << "[" << TRMFLT(tt[0]) << " " << TRMFLT(tt[2]) << " " << TRMFLT(tt[1])
 		      << " " << TRMFLT(tt[3]) << " 0 0] concat\n";
