@@ -1,11 +1,11 @@
 //---------------------------------------------------------------------------//
-// $Id: x26.cc 10169 2009-07-20 21:12:55Z andrewross $
+// $Id: x26.cc 10785 2010-01-31 20:05:17Z hezekiahcarty $
 // Multi-lingual version of the first page of example 4.
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
 // Copyright (C) 2006  Alan W. Irwin
-// Copyright (C) 2006  Andrew Ross 
+// Copyright (C) 2006  Andrew Ross
 //
 // Thanks to the following for providing translated strings for this example:
 // Valery Pipin (Russian)
@@ -70,152 +70,155 @@ using namespace std;
 
 
 static const char *x_label[] = {
-  "Frequency",
-  "Частота",
-  NULL
+    "Frequency",
+    "Частота",
+    NULL
 };
 
 static const char *y_label[] = {
-  "Amplitude (dB)",
-  "Амплитуда (dB)",
-  NULL
+    "Amplitude (dB)",
+    "Амплитуда (dB)",
+    NULL
 };
 
 static const char *alty_label[] = {
-  "Phase shift (degrees)",
-  "Фазовый сдвиг (градусы)",
-  NULL
+    "Phase shift (degrees)",
+    "Фазовый сдвиг (градусы)",
+    NULL
 };
 
 static const char *title_label[] = {
-  "Single Pole Low-Pass Filter",
-  "Однополюсный Низко-Частотный Фильтр",
-  NULL
+    "Single Pole Low-Pass Filter",
+    "Однополюсный Низко-Частотный Фильтр",
+    NULL
 };
 
 static const char *line_label[] = {
-  "-20 dB/decade",
-  "-20 dB/десяток",
-  NULL
+    "-20 dB/decade",
+    "-20 dB/десяток",
+    NULL
 };
 
 class x26 {
-
 public:
-  x26(int, const char **);
-  void plot1(int, const char*, const char*, const char*, const char*, const char*);
+    x26( int, const char ** );
+    void plot1( int, const char*, const char*, const char*, const char*, const char* );
 
 private:
-  // Class data
-  plstream *pls;
-
-
+    // Class data
+    plstream *pls;
 };
 
 
-x26::x26( int argc, const char ** argv ) {
+x26::x26( int argc, const char ** argv )
+{
+    int i;
 
-  int i;
+    // plplot initialization
 
-  // plplot initialization
+    pls = new plstream();
 
-  pls = new plstream();
+    // Parse and process command line arguments.
+    pls->parseopts( &argc, argv, PL_PARSE_FULL );
 
-  // Parse and process command line arguments.
-  pls->parseopts( &argc, argv, PL_PARSE_FULL );
+    // Initialize PLplot.
+    pls->init();
+    pls->font( 2 );
 
-  // Initialize PLplot.
-  pls->init();
-  pls->font(2);
+    // Make log plots using two different styles.
 
-  // Make log plots using two different styles.
+    i = 0;
+    while ( x_label[i] != NULL )
+    {
+        plot1( 0, x_label[i], y_label[i], alty_label[i], title_label[i],
+            line_label[i] );
+        i++;
+    }
 
-  i = 0;
-  while (x_label[i] != NULL) {
-      plot1(0, x_label[i], y_label[i], alty_label[i], title_label[i],
-                line_label[i]);
-      i++;
-  }
-
-  // pls->end();
-  delete pls;
+    // pls->end();
+    delete pls;
 }
 
 // Log-linear plot.
 
-void x26::plot1( int type, const char *x_label, const char *y_label, 
-           const char *alty_label, const char *title_label, 
-           const char *line_label ) {
-  int i;
-  PLFLT *freql = new PLFLT[101];
-  PLFLT *ampl  = new PLFLT[101];
-  PLFLT *phase = new PLFLT[101];
-  PLFLT f0, freq;
+void x26::plot1( int type, const char *x_label, const char *y_label,
+                 const char *alty_label, const char *title_label,
+                 const char *line_label )
+{
+    int   i;
+    PLFLT *freql = new PLFLT[101];
+    PLFLT *ampl  = new PLFLT[101];
+    PLFLT *phase = new PLFLT[101];
+    PLFLT f0, freq;
 
-  pls->adv(0);
+    pls->adv( 0 );
 
-  // Set up data for log plot.
+    // Set up data for log plot.
 
-  f0 = 1.0;
-  for (i = 0; i <= 100; i++) {
-    freql[i] = -2.0 + i / 20.0;
-    freq = pow(10.0, (double)freql[i]);
-    ampl[i] = 20.0 * log10(1.0 / sqrt(1.0 + pow((double)(freq / f0), 2.)));
-    phase[i] = -(180.0 / M_PI) * atan((double)(freq / f0));
-  }
+    f0 = 1.0;
+    for ( i = 0; i <= 100; i++ )
+    {
+        freql[i] = -2.0 + i / 20.0;
+        freq     = pow( 10.0, (double) freql[i] );
+        ampl[i]  = 20.0 * log10( 1.0 / sqrt( 1.0 + pow( (double) ( freq / f0 ), 2. ) ) );
+        phase[i] = -( 180.0 / M_PI ) * atan( (double) ( freq / f0 ) );
+    }
 
-  pls->vpor(0.15, 0.85, 0.1, 0.9);
-  pls->wind(-2.0, 3.0, -80.0, 0.0);
+    pls->vpor( 0.15, 0.85, 0.1, 0.9 );
+    pls->wind( -2.0, 3.0, -80.0, 0.0 );
 
-  // Try different axis and labelling styles.
+    // Try different axis and labelling styles.
 
-  pls->col0(1);
-  switch (type) {
-  case 0:
-    pls->box("bclnst", 0.0, 0, "bnstv", 0.0, 0);
-    break;
-  case 1:
-    pls->box("bcfghlnst", 0.0, 0, "bcghnstv", 0.0, 0);
-    break;
-  }
+    pls->col0( 1 );
+    switch ( type )
+    {
+    case 0:
+        pls->box( "bclnst", 0.0, 0, "bnstv", 0.0, 0 );
+        break;
+    case 1:
+        pls->box( "bcfghlnst", 0.0, 0, "bcghnstv", 0.0, 0 );
+        break;
+    }
 
-  // Plot ampl vs freq.
+    // Plot ampl vs freq.
 
-  pls->col0(2);
-  pls->line(101,freql, ampl);
-  pls->col0(1);
-  pls->ptex(1.6, -30.0, 1.0, -20.0, 0.5, line_label);
+    pls->col0( 2 );
+    pls->line( 101, freql, ampl );
+    pls->col0( 1 );
+    pls->ptex( 1.6, -30.0, 1.0, -20.0, 0.5, line_label );
 
-  // Put labels on.
+    // Put labels on.
 
-  pls->col0(1);
-  pls->mtex("b", 3.2, 0.5, 0.5, x_label);
-  pls->mtex("t", 2.0, 0.5, 0.5, title_label);
-  pls->col0(2);
-  pls->mtex("l", 5.0, 0.5, 0.5, y_label);
+    pls->col0( 1 );
+    pls->mtex( "b", 3.2, 0.5, 0.5, x_label );
+    pls->mtex( "t", 2.0, 0.5, 0.5, title_label );
+    pls->col0( 2 );
+    pls->mtex( "l", 5.0, 0.5, 0.5, y_label );
 
-  // For the gridless case, put phase vs freq on same plot.
+    // For the gridless case, put phase vs freq on same plot.
 
-  if (type == 0) {
-    pls->col0(1);
-    pls->wind(-2.0, 3.0, -100.0, 0.0);
-    pls->box("", 0.0, 0, "cmstv", 30.0, 3);
-    pls->col0(3);
-    pls->line(101,freql, phase);
-    pls->col0(3);
-    pls->mtex("r", 5.0, 0.5, 0.5, alty_label);
-  }
+    if ( type == 0 )
+    {
+        pls->col0( 1 );
+        pls->wind( -2.0, 3.0, -100.0, 0.0 );
+        pls->box( "", 0.0, 0, "cmstv", 30.0, 3 );
+        pls->col0( 3 );
+        pls->line( 101, freql, phase );
+        pls->col0( 3 );
+        pls->mtex( "r", 5.0, 0.5, 0.5, alty_label );
+    }
 
-  delete[] freql;
-  delete[] ampl;
-  delete[] phase;
+    delete[] freql;
+    delete[] ampl;
+    delete[] phase;
 }
 
 
-int main( int argc, const char ** argv ) {
-  x26 *x = new x26( argc, argv );
+int main( int argc, const char ** argv )
+{
+    x26 *x = new x26( argc, argv );
 
-  delete x;
+    delete x;
 }
 
 
