@@ -1,4 +1,4 @@
-!     $Id: x24f.f90 9346 2009-01-19 12:08:22Z andrewross $  
+!     $Id: x24f.f90 10618 2009-11-20 19:17:35Z airwin $  
 !
 !   Unicode Pace Flag
 !
@@ -154,7 +154,7 @@ program x24f
 
   do i = 1,4
 
-     call plcol0 (i);
+     call plcol0 (i)
      call plfill (px, py)
 
      do j = 1,4
