@@ -1,4 +1,4 @@
-(* $Id: x03.ml 10197 2009-08-02 05:29:20Z hezekiahcarty $
+(* $Id: x03.ml 10613 2009-11-19 12:05:09Z andrewross $
 
   Polar plot demo.
    Copyright (C) 2008, 2009  Hezekiah M. Carty
@@ -36,9 +36,9 @@ let main () =
   let y0 = Array.init 361 (fun i -> sin (dtr *. float_of_int i)) in
 
   (* Parse and process command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
-  (* Set orientation to landscape - note not all device drivers 
+  (* Set orientation to portrait - note not all device drivers 
    * support this, in particular most interactive drivers do not *)
   plsori 1;
 
