@@ -1,4 +1,4 @@
-(* $Id: x14.ml 9441 2009-02-03 06:32:28Z airwin $
+(* $Id: x14.ml 10793 2010-02-06 01:48:39Z hbabcock $
 
 	Demo of multiple stream/window capability (requires Tk or Tcl-DP).
 
@@ -225,42 +225,41 @@ let () =
 
   (* plplot initialization *)
   (* Parse and process command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
-  let driver = plgdev () in
-  let fam, num, bmax = plgfam () in
-  
   (* If valid geometry specified on command line, use it for both streams. *)
   let xp0, yp0, xleng0, yleng0, xoff0, yoff0 = plgpage () in
   let valid_geometry = ( xleng0 > 0 && yleng0 > 0 ) in
 
-  printf "Demo of multiple output streams via the %s driver.\n" driver;
-  printf "Running with the second stream as slave to the first.\n";
-  printf "\n";
-
   (* Set up first stream *)
   if valid_geometry then
     plspage xp0 yp0 xleng0 yleng0 xoff0 yoff0
   else
-    ignore (plsetopt "geometry" geometry_master);
+    plsetopt "geometry" geometry_master;
 
-  plsdev driver;
   plssub 2 2;
   plinit ();
 
+  let driver = plgdev () in
+  let fam, num, bmax = plgfam () in
+  
+  printf "Demo of multiple output streams via the %s driver.\n" driver;
+  printf "Running with the second stream as slave to the first.\n";
+  printf "\n";
+
   (* Start next stream *)
   plsstrm 1;
 
   if valid_geometry then
     plspage xp0 yp0 xleng0 yleng0 xoff0 yoff0
   else
-    ignore (plsetopt "geometry" geometry_slave);
+    plsetopt "geometry" geometry_slave;
 
   (* Turn off pause to make this a slave (must follow master) *)
   plspause false;
   plsdev driver;
   plsfam fam num bmax;
-  ignore (plsetopt "fflen" "2");
+  plsetopt "fflen" "2";
   plinit ();
 
   (* Set up the data & plot *)
