@@ -1,4 +1,4 @@
-(* $Id: x29.ml 10288 2009-08-18 18:48:18Z hezekiahcarty $
+(* $Id: x29.ml 10463 2009-09-23 20:56:58Z hezekiahcarty $
 
        Sample plots using date / time formatting for axes
 
@@ -339,7 +339,7 @@ let plot4 () =
 \*--------------------------------------------------------------------------*)
 let () =
   (* Parse command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
   (* Initialize plplot *)
   plinit ();
