@@ -1,4 +1,4 @@
-(* $Id: x31.ml 9653 2009-03-02 15:54:09Z andrewross $
+(* $Id: x31.ml 10464 2009-09-23 20:57:49Z hezekiahcarty $
 
   Copyright (C) 2008 Alan W. Irwin
   Copyright (C) 2008 Andrew Ross
@@ -42,7 +42,7 @@ let () =
   in
 
   (* Parse and process command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
   (* Test setting / getting familying parameters before plinit *)
   (* Save values set by plparseopts to be restored later. *)
@@ -107,10 +107,14 @@ let () =
   plscol0 1 255 0 0;
   plscmap1 r1 g1 b1;
   plscmap1a r1 g1 b1 a1;
-  
+
   let level2 = plglevel () in
-  printf "level parameter = %d\n" level2;
-  failed_if (level2 != 1) "plglevel test failed.\n";
+  (* WARNING: The use of Obj.magic here is a cheat.  This really should be
+     replaced by a proper int_of_plplot_run_level function.  This example is
+     the only place it would be needed though, so it is not worth it at
+     this time. *)
+  printf "level parameter = %d\n" (Obj.magic level2);
+  failed_if (level2 <> PL_INITIALIZED) "plglevel test failed.\n";
 
   pladv 0;
   plvpor 0.01 0.99 0.02 0.49;
