@@ -56,23 +56,16 @@ sub main {
 
   plParseOpts (\@ARGV, PL_PARSE_SKIP | PL_PARSE_NOPROGRAM);
 
-  my $driver = plgdev ();
-  my ($fam, $num, $bmax) = plgfam ();
-
-  print ("Demo of multiple output streams via the $driver driver.\n"
-         . "Running with the second stream as slave to the first.\n"
-         . "\n");
-
   # If valid geometry specified on command line, use it for both streams.
   my ($xp0, $yp0, $xleng0, $yleng0, $xoff0, $yoff0) = plgpage ();
-  printf("%s %i, %i\n", "xleng0, yleng0 = ", $xleng0, $yleng0);
+  #printf("%s %i, %i\n", "xleng0, yleng0 = ", $xleng0, $yleng0);
   my $valid_geometry;
   if ($xleng0 > 0 && $yleng0 > 0) {
     $valid_geometry = 1;
   } else {
     $valid_geometry = 0;
   }
-  printf("%s %i\n", "valid_geometry = ", $valid_geometry);
+  #printf("%s %i\n", "valid_geometry = ", $valid_geometry);
 
   # Set up first stream
 
@@ -82,10 +75,16 @@ sub main {
     plsetopt ("geometry", $geometry_master);
   }
 
-  plsdev ($driver);
   plssub (2, 2);
   plinit ();
 
+  my $driver = plgdev ();
+  my ($fam, $num, $bmax) = plgfam ();
+
+  print ("Demo of multiple output streams via the $driver driver.\n"
+         . "Running with the second stream as slave to the first.\n"
+         . "\n");
+
   # Start next stream
 
   plsstrm (1);
