@@ -1,4 +1,4 @@
-# $Id: xw19.py 10250 2009-08-14 07:41:34Z andrewross $
+# $Id: xw19.py 11001 2010-05-17 12:33:24Z andrewross $
 
 #  Copyright (C) Wesley Ebisuzaki
 #  Copyright (C) 2009 Andrew Ross
@@ -24,6 +24,12 @@
 
 from plplot_py_demos import *
 
+def map_transform( x, y, xt, yt, data ):
+
+    radius = 90.0 - y
+    xt[0]    = radius * cos( x * pi / 180.0 )
+    yt[0]    = radius * sin( x * pi / 180.0 )
+
 # mapform19
 #
 # Defines specific coordinate transformation for example 19.
@@ -33,7 +39,7 @@ def mapform19(n, x, y):
     for i in range(n):
         radius = 90.0 - y[i]
         xp = radius * cos(x[i] * pi / 180.0)
-	yp = radius * sin(x[i] * pi / 180.0)
+        yp = radius * sin(x[i] * pi / 180.0)
 	x[i] = xp
 	y[i] = yp
     return [x,y]
@@ -127,4 +133,32 @@ def main():
     pllsty(2)
     plmeridians(mapform19,10.0, 10.0, 0.0, 360.0, -10.0, 80.0)
 
+    # Polar, Northern hemisphere, this time with a PLplot-wide transform
+
+    minx = 0
+    maxx = 360
+
+    plstransform( map_transform, None )
+
+    pllsty( 1 )
+    plenv( -75., 75., -75., 75., 1, -1 )
+    # No need to set the map transform here as the global transform will be
+    # used.
+    plmap( None, "globe", minx, maxx, miny, maxy )
+
+    pllsty( 2 )
+    plmeridians( None, 10.0, 10.0, 0.0, 360.0, -10.0, 80.0 )
+
+    # Show Baltimore, MD on the map
+    plcol0( 2 )
+    plssym( 0.0, 2.0 )
+    x = [ -76.6125 ]
+    y = [ 39.2902778 ]
+    plpoin( x, y, 18 )
+    plssym( 0.0, 1.0 )
+    plptex( -76.6125, 43.0, 0.0, 0.0, 0.0, "Baltimore, MD" )
+
+    # For C, this is how the global transform is cleared 
+    plstransform( None, None )
+
 main()
