@@ -1,4 +1,4 @@
-# $Id: xw30.py 9149 2008-12-16 19:43:33Z airwin $
+# $Id: xw30.py 10659 2009-12-02 01:10:08Z airwin $
 
 #  Copyright (C) 2008 Hazen Babcock
 #  Copyright (C) 2008 Andrew Ross
@@ -112,27 +112,23 @@ def main():
       py[3] = py[2]
       plfill(px, py)
 
-  # The overlaid box is drawn using plshades with a color map that is 
-  # the same color but has a linearly varying transparency. 
-
   # Create the color map with 128 colors and use plscmap1la to initialize 
-  # the color values with a linear varying transparency (or alpha) 
+  # the color values with a linearly varying red transparency (or alpha) 
   plscmap1n(128)
   plscmap1la(1, pos, rcoord, gcoord, bcoord, acoord, rev)
 
-  # Create a 2 x 2 array that contains the z values (0.0 to 1.0) that will 
-  # used for the shade plot. plshades will use linear interpolation to 
-  # calculate the z values of all the intermediate points in this array.
-  z = reshape(zeros(2*2),(2,2))
-  z[0][1] = 1.0
-  z[1][1] = 1.0
-
-  # Set the color levels array. These levels are also between 0.0 and 1.0
-  clevel = 0.01*arange(101)
-
-  # Draw the shade plot with zmin = 0.0, zmax = 1.0 and x and y coordinate 
-  # ranges such that it fills the entire plotting area. 
-  plshades(z, 0.0, 1.0, 0.0, 1.0, clevel, 0, 1)
+  # Use that cmap1 to create a transparent red gradient for the whole
+  # window.
+  px[0] = 0.
+  px[1] = 1.
+  px[2] = 1.
+  px[3] = 0.
+   
+  py[0] = 0.
+  py[1] = 0.
+  py[2] = 1.
+  py[3] = 1.
 
+  plgradient(px, py, 90.)
 
 main()
