@@ -1,4 +1,4 @@
-# $Id: x17.tcl 9916 2009-05-05 11:15:34Z andrewross $
+# $Id: x17.tcl 11026 2010-05-27 09:56:37Z andrewross $
 #
 #      Copyright (C) 2009  Arjen Markus
 #
@@ -128,4 +128,7 @@ proc x17 {{w loopback}} {
 #   Destroy strip chart and it's memory
 
     $w cmd plstripd $id1
+
+#   Restore defaults
+    $w cmd pllsty 1
 }
