@@ -1,4 +1,4 @@
-#      $Id: x21.tcl 9916 2009-05-05 11:15:34Z andrewross $
+#      $Id: x21.tcl 11026 2010-05-27 09:56:37Z andrewross $
 #      Grid data demo.
 #
 #      Copyright (C) 2004  Joao Cardoso
@@ -27,11 +27,6 @@
 
 proc x21 {{w loopback}} {
 
-    if { [catch {package require Tcl 8.5}] } {
-        puts "This example require Tcl 8.5 or later: use of NaNs"
-        return
-    }
-
     set PI          [expr {4.0*atan(1.0)}]
 
     set GRID_CSA    1
@@ -204,7 +199,7 @@ proc x21 {{w loopback}} {
                 $w cmd plenv0 $xmin $xmax $ymin $ymax 2 0
                 $w cmd plcol0 15
                 $w cmd pllab "X" "Y" [lindex $title $alg]
-                $w cmd plshades zg $xmin $xmax $ymin $ymax clev 1 0 1 2
+                $w cmd plshades zg $xmin $xmax $ymin $ymax clev 1 0 1 1 "NULL"
                 $w cmd plcol0 2
             } else {
 
@@ -236,7 +231,8 @@ proc x21 {{w loopback}} {
     }
 
     $w cmd plflush
-    $w cmd plend
+    #$w cmd plend
+    $w cmd plssub 1 1
 }
 
 #----------------------------------------------------------------------------
