@@ -15,16 +15,17 @@
  *
  *****************************************************************************/
 
-#if !defined(_NN_H)
+#if !defined ( _NN_H )
 #define _NN_H
 
 #include "nndll.h"
 
-typedef enum { SIBSON, NON_SIBSONIAN } NN_RULE;
+typedef enum { SIBSON, NON_SIBSONIAN }   NN_RULE;
 
-#if !defined(_POINT_STRUCT)
+#if !defined ( _POINT_STRUCT )
 #define _POINT_STRUCT
-typedef struct {
+typedef struct
+{
     double x;
     double y;
     double z;
@@ -32,46 +33,46 @@ typedef struct {
 #endif
 
 /** Smoothes the input point array by averaging the input x,y and z values
- ** for each cell within virtual rectangular nx by ny grid. The corners of the
- ** grid are created from min and max values of the input array. It also frees
- ** the original array and returns results and new dimension via original
- ** data and size pointers.
- *
- * @param pn Pointer to number of points (input/output)
- * @param ppoints Pointer to array of points (input/output) [*pn]
- * @param nx Number of x nodes in decimation
- * @param ny Number of y nodes in decimation
- */
-void points_thin(int* n, point** points, int nx, int ny);
+** for each cell within virtual rectangular nx by ny grid. The corners of the
+** grid are created from min and max values of the input array. It also frees
+** the original array and returns results and new dimension via original
+** data and size pointers.
+*
+* @param pn Pointer to number of points (input/output)
+* @param ppoints Pointer to array of points (input/output) [*pn]
+* @param nx Number of x nodes in decimation
+* @param ny Number of y nodes in decimation
+*/
+void points_thin( int* n, point** points, int nx, int ny );
 
 /** Generates rectangular grid nx by ny using min and max x and y values from
- ** the input point array. Allocates space for the output point array, be sure
- ** to free it when necessary!
- *
- * @param n Number of points
- * @param points Array of points [n]
- * @param nx Number of x nodes
- * @param ny Number of y nodes
- * @param nout Pointer to number of output points
- * @param pout Ppointer to array of output points [*nout]
- */
-void points_generate1(int n, point points[], int nx, int ny, double zoom, int* nout, point** pout);
+** the input point array. Allocates space for the output point array, be sure
+** to free it when necessary!
+*
+* @param n Number of points
+* @param points Array of points [n]
+* @param nx Number of x nodes
+* @param ny Number of y nodes
+* @param nout Pointer to number of output points
+* @param pout Ppointer to array of output points [*nout]
+*/
+void points_generate1( int n, point points[], int nx, int ny, double zoom, int* nout, point** pout );
 
-/** Generates rectangular grid nx by ny using specified min and max x and y 
- ** values. Allocates space for the output point array, be sure to free it
- ** when necessary!
- *
- * @param xmin Min x value
- * @param xmax Max x value
- * @param ymin Min y value
- * @param ymax Max y value
- * @param nx Number of x nodes
- * @param ny Number of y nodes
- * @param zoom Zoom coefficient
- * @param nout Pointer to number of output points
- * @param pout Pointer to array of output points [*nout]
- */
-void points_generate2(double xmin, double xmax, double ymin, double ymax, int nx, int ny, int* nout, point** pout);
+/** Generates rectangular grid nx by ny using specified min and max x and y
+** values. Allocates space for the output point array, be sure to free it
+** when necessary!
+*
+* @param xmin Min x value
+* @param xmax Max x value
+* @param ymin Min y value
+* @param ymax Max y value
+* @param nx Number of x nodes
+* @param ny Number of y nodes
+* @param zoom Zoom coefficient
+* @param nout Pointer to number of output points
+* @param pout Pointer to array of output points [*nout]
+*/
+void points_generate2( double xmin, double xmax, double ymin, double ymax, int nx, int ny, int* nout, point** pout );
 
 /** Reads array of points from a columnar file.
  *
@@ -80,16 +81,16 @@ void points_generate2(double xmin, double xmax, double ymin, double ymax, int nx
  * @param n Pointer to number of points (output)
  * @param points Pointer to array of points [*n] (output)
  */
-void points_read(char* fname, int dim, int* n, point** points);
+void points_read( char* fname, int dim, int* n, point** points );
 
 /** Scales Y coordinate so that the resulting set fits into square:
- ** xmax - xmin = ymax - ymin
- *
- * @param n Number of points
- * @param points The points to scale
- * @return Y axis compression coefficient
- */
-double points_scaletosquare(int n, point* points);
+** xmax - xmin = ymax - ymin
+*
+* @param n Number of points
+* @param points The points to scale
+* @return Y axis compression coefficient
+*/
+double points_scaletosquare( int n, point* points );
 
 /** Compresses Y domain by a given multiple.
  *
@@ -97,7 +98,7 @@ double points_scaletosquare(int n, point* points);
  * @param points The points to scale
  * @param Y axis compression coefficient as returned by points_scaletosquare()
  */
-void points_scale(int n, point* points, double k);
+void points_scale( int n, point* points, double k );
 
 /** Structure to perform the Delaunay triangulation of a given array of points.
  *
@@ -107,7 +108,7 @@ void points_scale(int n, point* points, double k);
  * Contains point to triangle map.
  */
 struct delaunay;
-typedef struct delaunay delaunay;
+typedef struct delaunay   delaunay;
 
 /** Builds Delaunay triangulation of the given array of points.
  *
@@ -119,13 +120,13 @@ typedef struct delaunay delaunay;
  * @param holes Array of hole (x,y) coordinates [2*nh]
  * @return Delaunay triangulation with triangulation results
  */
-delaunay* delaunay_build(int np, point points[], int ns, int segments[], int nh, double holes[]);
+delaunay* delaunay_build( int np, point points[], int ns, int segments[], int nh, double holes[] );
 
 /** Destroys Delaunay triangulation.
  *
  * @param d Structure to be destroyed
  */
-void delaunay_destroy(delaunay* d);
+void delaunay_destroy( delaunay* d );
 
 /** `lpi' -- "linear point interpolator" is a structure for
  * conducting linear interpolation on a given data on a "point-to-point" basis.
@@ -134,27 +135,27 @@ void delaunay_destroy(delaunay* d);
  * Natural Neighbours interpolators below.
  */
 struct lpi;
-typedef struct lpi lpi;
+typedef struct lpi   lpi;
 
 /** Builds linear interpolator.
  *
  * @param d Delaunay triangulation
  * @return Linear interpolator
  */
-lpi* lpi_build(delaunay* d);
+lpi* lpi_build( delaunay* d );
 
 /** Destroys linear interpolator.
  *
  * @param l Structure to be destroyed
  */
-void lpi_destroy(lpi* l);
+void lpi_destroy( lpi* l );
 
 /** Finds linearly interpolated value in a point.
  *
  * @param l Linear point interpolator
  * @param p Point to be interpolated (p->x, p->y -- input; p->z -- output)
  */
-void lpi_interpolate_point(lpi* l, point* p);
+void lpi_interpolate_point( lpi* l, point* p );
 
 /* Linearly interpolates data from one array of points for another array of
  * points.
@@ -165,55 +166,55 @@ void lpi_interpolate_point(lpi* l, point* p);
  * @param pout Array of output points [nout]
  */
 NNDLLIMPEXP
-void lpi_interpolate_points(int nin, point pin[], int nout, point pout[]);
+void lpi_interpolate_points( int nin, point pin[], int nout, point pout[] );
 
 /** `nnpi' -- "Natural Neighbours point interpolator" is a
  * structure for conducting Natural Neighbours interpolation on a given data on
  * a "point-to-point" basis. Because it involves weight calculation for each
  * next output point, it is not particularly suitable for consequitive
- * interpolations on the same set of observation points -- use 
+ * interpolations on the same set of observation points -- use
  * `nnhpi' or `nnai' in these cases.
  */
 struct nnpi;
-typedef struct nnpi nnpi;
+typedef struct nnpi   nnpi;
 
 /** Creates Natural Neighbours point interpolator.
  *
  * @param d Delaunay triangulation
  * @return Natural Neighbours interpolation
  */
-nnpi* nnpi_create(delaunay* d);
+nnpi* nnpi_create( delaunay* d );
 
 /** Destroys Natural Neighbours point interpolation.
  *
  * @param nn Structure to be destroyed
  */
-void nnpi_destroy(nnpi* nn);
+void nnpi_destroy( nnpi* nn );
 
 /** Finds Natural Neighbours-interpolated value in a point.
  *
  * @param nn NN point interpolator
  * @param p Point to be interpolated (p->x, p->y -- input; p->z -- output)
  */
-void nnpi_interpolate_point(nnpi* nn, point* p);
+void nnpi_interpolate_point( nnpi* nn, point* p );
 
 /** Natural Neighbours-interpolates data in one array of points for another
- ** array of points.
- *
- * @param nin Number of input points
- * @param pin Array of input points [pin]
- * @param wmin Minimal allowed weight
- * @param nout Number of output points
- * @param pout Array of output points [nout]
- */
+** array of points.
+*
+* @param nin Number of input points
+* @param pin Array of input points [pin]
+* @param wmin Minimal allowed weight
+* @param nout Number of output points
+* @param pout Array of output points [nout]
+*/
 NNDLLIMPEXP
-void nnpi_interpolate_points(int nin, point pin[], double wmin, int nout, point pout[]);
+void nnpi_interpolate_points( int nin, point pin[], double wmin, int nout, point pout[] );
 
 /** Sets minimal allowed weight for Natural Neighbours interpolation.
  * @param nn Natural Neighbours point interpolator
  * @param wmin Minimal allowed weight
  */
-void nnpi_setwmin(nnpi* nn, double wmin);
+void nnpi_setwmin( nnpi* nn, double wmin );
 
 /** `nnhpi' is a structure for conducting consequitive
  * Natural Neighbours interpolations on a given spatial data set in a random
@@ -222,7 +223,7 @@ void nnpi_setwmin(nnpi* nn, double wmin);
  * coordinate of data between interpolations.
  */
 struct nnhpi;
-typedef struct nnhpi nnhpi;
+typedef struct nnhpi   nnhpi;
 
 /** Creates Natural Neighbours hashing point interpolator.
  *
@@ -230,20 +231,20 @@ typedef struct nnhpi nnhpi;
  * @param size Hash table size (should be of order of number of output points)
  * @return Natural Neighbours interpolation
  */
-nnhpi* nnhpi_create(delaunay* d, int size);
+nnhpi* nnhpi_create( delaunay* d, int size );
 
 /** Destroys Natural Neighbours hashing point interpolation.
  *
  * @param nn Structure to be destroyed
  */
-void nnhpi_destroy(nnhpi* nn);
+void nnhpi_destroy( nnhpi* nn );
 
 /** Finds Natural Neighbours-interpolated value in a point.
  *
  * @param nnhpi NN hashing point interpolator
  * @param p Point to be interpolated (p->x, p->y -- input; p->z -- output)
  */
-void nnhpi_interpolate(nnhpi* nn, point* p);
+void nnhpi_interpolate( nnhpi* nn, point* p );
 
 /** Modifies interpolated data.
  * Finds point* pd in the underlying Delaunay triangulation such that
@@ -253,13 +254,13 @@ void nnhpi_interpolate(nnhpi* nn, point* p);
  * @param nn Natural Neighbours hashing point interpolator
  * @param p New data
  */
-void nnhpi_modify_data(nnhpi* nn, point* p);
+void nnhpi_modify_data( nnhpi* nn, point* p );
 
 /** Sets minimal allowed weight for Natural Neighbours interpolation.
  * @param nn Natural Neighbours point hashing interpolator
  * @param wmin Minimal allowed weight
  */
-void nnhpi_setwmin(nnhpi* nn, double wmin);
+void nnhpi_setwmin( nnhpi* nn, double wmin );
 
 /* `nnai' is a tructure for conducting consequitive Natural
  * Neighbours interpolations on a given spatial data set in a given array of
@@ -268,7 +269,7 @@ void nnhpi_setwmin(nnhpi* nn, double wmin);
  * interpolators here.
  */
 struct nnai;
-typedef struct nnai nnai;
+typedef struct nnai   nnai;
 
 /** Builds Natural Neighbours array interpolator. This includes calculation of
  * weights used in nnai_interpolate().
@@ -276,15 +277,15 @@ typedef struct nnai nnai;
  * @param d Delaunay triangulation
  * @return Natural Neighbours interpolation
  */
-nnai* nnai_build(delaunay* d, int n, double* x, double* y);
+nnai* nnai_build( delaunay* d, int n, double* x, double* y );
 
 /** Destroys Natural Neighbours array interpolator.
  *
  * @param nn Structure to be destroyed
  */
-void nnai_destroy(nnai* nn);
+void nnai_destroy( nnai* nn );
 
-/** Conducts NN interpolation in a fixed array of output points using 
+/** Conducts NN interpolation in a fixed array of output points using
  * data specified for a fixed array of input points. Uses pre-calculated
  * weights.
  *
@@ -292,13 +293,13 @@ void nnai_destroy(nnai* nn);
  * @param zin input data [nn->d->npoints]
  * @param zout output data [nn->n]. Must be pre-allocated!
  */
-void nnai_interpolate(nnai* nn, double* zin, double* zout);
+void nnai_interpolate( nnai* nn, double* zin, double* zout );
 
 /** Sets minimal allowed weight for Natural Neighbours interpolation.
  * @param nn Natural Neighbours array interpolator
  * @param wmin Minimal allowed weight
  */
-void nnai_setwmin(nnai* nn, double wmin);
+void nnai_setwmin( nnai* nn, double wmin );
 
 /* Sets the verbosity level within nn package.
  * 0 (default) - silent
@@ -311,7 +312,7 @@ extern int nn_verbose;
  * SIBSON -- classic Sibson method
  * NON_SIBSONIAN -- simpler and (I think) more robust method
  */
-extern NNDLLIMPEXP_DATA(NN_RULE) nn_rule;
+extern NNDLLIMPEXP_DATA( NN_RULE ) nn_rule;
 
 /* Contains version string for the nn package.
  */
